package com.ruoyi.mybasic.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.security.utils.SecurityUtils;
import com.ruoyi.mybasic.common.domain.request.PurseRequest;
import com.ruoyi.mybasic.common.domain.response.PurseResponse;
import com.ruoyi.mybasic.service.PurseService;
import com.ruoyi.mybasic.service.PurseServiceTwo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.security.*;

/**
 * @ClassName PurseControllerTwo
 * @Description 我的钱包模块接口
 * @Author WenHao.Sao
 */
@RestController
@RequestMapping("purse")
public class PurseControllerTwo {

    @Autowired
    private PurseServiceTwo purseServiceTwo;

    /**
     * 钱包信息接口：
     * 入参：无
     * 出参：钱包对象
     * 说明：获取当前用户id securityUtils.getUserId()
     * 根据userId查询钱包表
     */
    @GetMapping("/purseObject")
    public R<PurseResponse> purseObject(){
        //当前登录人的UserId
        Long userId = SecurityUtils.getUserId();
        return purseServiceTwo.purseObject(userId);
    }

    /**
     * 充值接口：
     * 入参: 微信/充值宝渠道 充值金额
     * 出参：统一结果集
     * 说明根据入参调用微信/支付宝 api接口
     * 添加一条专门的充值记录表 状态为待处理
     * 封装api接口需要的参数对象（新增充值记录的id 微信/支付宝 充值金额等），把对象给消息队列
     * 消息队列根据消息调用api接口 消息队列根据api接口的返回结果进行不同的操作
     * 根据api接口返回结果消息队列中的操作失败：根据参数中的充值记录id 把对应记录状态改为失败
     * 成功：根据参数中的充值记录id 把对应记录状态改为成功 用户的余额增加 增加一条收支记录表
     */


    /**
     * 提现接口：
     * 入参:提现金额 绑定的银行卡id
     * 出参：统一结果集
     * 说明：先进行余额判断，判断账号钱币是否足够 不够则提示用户
     * 添加一条专门的提现记录 状态为待处理
     * 封装api接口需要的参数对象（新增提现记录的id 银行卡id 提现金额等）,把对象给消息队列
     * 消息队列根据消息调用api接口 消息队列根据api接口的返回结果进行不同的操作失败：根据参数中的提现记录id 把对应记录状态改为失败
     * 成功：根据参数中的充值记录id 把对应记录状态改为成功 用户的余额减少 增加一条收支记录表
     */


    /**
     * 钱包余额改变接口：
     * 入参：对象(userId,钱币数量,收入/支出标识，类型)
     * 出参：统一结果集
     * 说明：如果是支出也要先进行余额判断
     * 根据参数给对应用户钱包的余额进行改变
     * 添加一条收支记录表
     */
    @PostMapping("/purseBalanceChange")
    public R purseBalanceChange(@RequestBody PurseRequest purseRequest){
        return purseServiceTwo.purseBalanceChange(purseRequest);
    }



    /**
     *添加钱包：
     * 入参：userId
     * 出参：统一结果集
     * 说明：根据userId添加钱包
     */
    @PostMapping("/addPurse/{userId}")
    public R addPurse(@PathVariable String userId){
        return purseServiceTwo.addPurse(userId);
    }

}
