package com.ruoyi.mybasic.service.Impl;

import com.ruoyi.mybasic.common.domain.UserMoneyLogs;
import com.ruoyi.mybasic.common.domain.request.RequestInvitationRecord;
import com.ruoyi.mybasic.mapper.InvitationMapper;
import com.ruoyi.mybasic.service.InvitationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;

/**
 * @ClassName InvitationServiceImpl
 * @Description 邀请记录业务层
 * @Author WenHao.Sao
 */
/**
 * 邀请获利实现层
 * @author Lou_Zs
 */
@Service
public class InvitationServiceImpl implements InvitationService {

    /** @noinspection SpringJavaInjectionPointsAutowiringInspection*/
    @Autowired
    private InvitationMapper invitationMapper;



    /**
     * 新用户注册邀请获利
     * @param requestInvitationRecord
     */
    @Override
    @Transactional //事务
    public void UserInviteTask(RequestInvitationRecord requestInvitationRecord) {
        int i = 0;
        //新增一条邀请记录
        i = invitationMapper.insertInvitationRecord(requestInvitationRecord);
        if (i < 0){
            throw new RuntimeException("该用户未完成邀请");
        }
        //被邀请人id
        Integer userPid = requestInvitationRecord.getUserPid();
        //邀请人id
        Integer userId = requestInvitationRecord.getUserId();

        //修改邀请人钱包 (1.可用余额+300 2.总计收入+300 3.修改时间)
        i = invitationMapper.updateUserPurse(userId);
        if (i < 0){
            throw new RuntimeException("获利金额未增加到可用余额");
        }
        //同时添加钱包变更记录表
        UserMoneyLogs PurseMoneyLogs = new UserMoneyLogs();
        PurseMoneyLogs.setUserId(userId);
        PurseMoneyLogs.setMoneyTypeName("NEW_USER_INVITE");
        PurseMoneyLogs.setStatus(2);
        PurseMoneyLogs.setAmountIncome(300);
        PurseMoneyLogs.setCreateTime(new Date());
        invitationMapper.insertUserMoneyLogs(PurseMoneyLogs);


        //修改被邀请人钱包 (1.可用余额+300 2.总计收入+300 3.修改时间)
        i = invitationMapper.updateUserPurse(userPid);
        if (i < 0){
            throw new RuntimeException("获利金额未增加到可用余额");
        }
        //同时添加钱包变更记录表
        UserMoneyLogs PurseMoneyLogsTwo = new UserMoneyLogs();
        PurseMoneyLogsTwo.setUserId(userPid);
        PurseMoneyLogsTwo.setMoneyTypeName("NEW_USER_INVITE");
        PurseMoneyLogsTwo.setStatus(2);
        PurseMoneyLogsTwo.setAmountIncome(300);
        PurseMoneyLogsTwo.setCreateTime(new Date());
        invitationMapper.insertUserMoneyLogs(PurseMoneyLogsTwo);

    }
}
