package com.ruoyi.mybasic.service.Impl;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.mybasic.common.domain.request.MoneyLogsRequest;
import com.ruoyi.mybasic.common.domain.request.PurseRequest;
import com.ruoyi.mybasic.common.domain.response.PurseResponse;
import com.ruoyi.mybasic.mapper.PurseMapperTwo;
import com.ruoyi.mybasic.service.PurseServiceTwo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @ClassName PurseServiceTwoImpl
 * @Description 描述
 * @Author WenHao.Sao
 */
@Service
public class PurseServiceTwoImpl implements PurseServiceTwo {

    /** @noinspection SpringJavaInjectionPointsAutowiringInspection*/
    @Autowired
    private PurseMapperTwo purseMapperTwo;

    /**
     * 根据当前登录的用户userId
     * 获取到当前钱包对象
     * @param userId
     * @return
     */
    @Override
    public R<PurseResponse> purseObject(Long userId) {
        PurseResponse purseResponse = purseMapperTwo.purseObject(userId);
        R<PurseResponse> ok = R.ok(purseResponse);
        return ok;
    }

    /**
     * 充值接口：
     * 入参: 微信/充值宝渠道 充值金额
     * 出参：统一结果集
     * 说明根据入参调用微信/支付宝 api接口
     * 添加一条专门的充值记录表 状态为待处理
     * 封装api接口需要的参数对象（新增充值记录的id 微信/支付宝 充值金额等），把对象给消息队列
     * 消息队列根据消息调用api接口 消息队列根据api接口的返回结果进行不同的操作
     * 根据api接口返回结果消息队列中的操作失败：根据参数中的充值记录id 把对应记录状态改为失败
     * 成功：根据参数中的充值记录id 把对应记录状态改为成功 用户的余额增加 增加一条收支记录表
     */


    /**
     * 提现接口：
     * 入参:提现金额 绑定的银行卡id
     * 出参：统一结果集
     * 说明：先进行余额判断，判断账号钱币是否足够 不够则提示用户
     * 添加一条专门的提现记录 状态为待处理
     * 封装api接口需要的参数对象（新增提现记录的id 银行卡id 提现金额等）,把对象给消息队列
     * 消息队列根据消息调用api接口 消息队列根据api接口的返回结果进行不同的操作失败：根据参数中的提现记录id 把对应记录状态改为失败
     * 成功：根据参数中的充值记录id 把对应记录状态改为成功 用户的余额减少 增加一条收支记录表
     */


    /**
     * 钱包余额改变接口：
     * 入参：对象(userId,钱币数量,收入/支出标识，类型)
     * 出参：统一结果集
     * 说明：如果是支出也要先进行余额判断
     * 根据参数给对应用户钱包的余额进行改变
     * 添加一条收支记录表
     */
    @Override
    public R purseBalanceChange(PurseRequest purseRequest) {
        //修改余额
//        Integer i = purseMapperTwo.updPurse(purseRequest);

        //获取入参的金额
        int amount = purseRequest.getAmount();
        //转型
        Double doubleAmount = Double.valueOf(amount);

        //获取当前用户userId
        String userId = purseRequest.getUserId();

        //获取当前用户的余额
        PurseResponse purseResponse = purseMapperTwo.purseObject(Long.valueOf(userId));
        //当前用户的余额
        Double balanceFee = purseResponse.getBalanceFee();
            //获取到状态是收入还是支出 1：支出 2 收入
            int status = purseRequest.getStatus();
            //如果是支出 进行入参金额 和 原有金额 进行判断
            if (1 == status && doubleAmount <= balanceFee){
                //进行修改余额 支出
                purseMapperTwo.updPurseIn(purseRequest);
            }else{
                return R.fail("余额不足");
            }
            //收入
            if (2 == status){
                //进行修改余额 收入
                purseMapperTwo.updPurseOut(purseRequest);
            }
            //获取到收入 支出 记录表 对象
            MoneyLogsRequest moneyLogsRequest = new MoneyLogsRequest();
            moneyLogsRequest.setUserId(Long.valueOf(purseRequest.getUserId()));//登录人
            moneyLogsRequest.setStatus(status);//状态 1:支出 2:收入
            moneyLogsRequest.setAmountIncome(amount + "");//入参金额
            moneyLogsRequest.setCreateTime(new Date());//创建时间
            moneyLogsRequest.setCreateUserId(purseRequest.getUserId());//创建人
            //添加记录表中
            purseMapperTwo.addMoneyLogs(moneyLogsRequest);
            return R.ok("金额修改成功");
    }

    /**
     * 根据userId 添加钱包
     * @param userId
     * @return
     */
    @Override
    public R addPurse(String userId) {
        Integer purseUserId = purseMapperTwo.purseUserId(userId);
        if (purseUserId != null ){
            return R.fail("已有该用户,请重新创建");
        }else{
            PurseRequest purseRequest = new PurseRequest();
            purseRequest.setUserId(userId);
            purseRequest.setUpdateTime(new Date());
            Integer i = purseMapperTwo.addPurse(purseRequest);
            if (i>0){
                return R.ok("成功");
            }else{
                return R.fail("失败");
            }
        }
    }


}
